============
Installation
============

The package is available for install via ``pip``.
To install the latest stable version,
you can run:

.. code-block:: shell-session

    pip install rimseval

To get the latest development version,
add the ``--pre`` flag to the installation command.
To get the latest developments from GitHub,
the package can be installed via:

.. code-block:: shell-session

    pip install git+https://github.com/RIMS-Code/RIMSEval.git

Installations for development are easiest done
after cloning the repo.
Enter the folder and install the package editable by typing:

.. code-block:: shell-session

    pip install -e .
